==> tekton-model-triggers-v1alpha1-6.5.0-sources.jar: io/fabric8/tekton/triggers/v1alpha1/ClusterInterceptorListFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ClusterInterceptorListFluent<A extends ClusterInterceptorListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,ClusterInterceptor item);
  public A setToItems(Integer index,ClusterInterceptor item);
  public A addToItems(io.fabric8.tekton.triggers.v1alpha1.ClusterInterceptor... items);
  public A addAllToItems(Collection<ClusterInterceptor> items);
  public A removeFromItems(io.fabric8.tekton.triggers.v1alpha1.ClusterInterceptor... items);
  public A removeAllFromItems(Collection<ClusterInterceptor> items);
  public A removeMatchingFromItems(Predicate<ClusterInterceptorBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClusterInterceptor> getItems();
  public List<ClusterInterceptor> buildItems();
  public ClusterInterceptor buildItem(Integer index);
  public ClusterInterceptor buildFirstItem();
  public ClusterInterceptor buildLastItem();
  public ClusterInterceptor buildMatchingItem(Predicate<ClusterInterceptorBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ClusterInterceptorBuilder> predicate);
  public A withItems(List<ClusterInterceptor> items);
  public A withItems(io.fabric8.tekton.triggers.v1alpha1.ClusterInterceptor... items);
  public Boolean hasItems();
  public ClusterInterceptorListFluent.ItemsNested<A> addNewItem();
  public ClusterInterceptorListFluent.ItemsNested<A> addNewItemLike(ClusterInterceptor item);
  public ClusterInterceptorListFluent.ItemsNested<A> setNewItemLike(Integer index,ClusterInterceptor item);
  public ClusterInterceptorListFluent.ItemsNested<A> editItem(Integer index);
  public ClusterInterceptorListFluent.ItemsNested<A> editFirstItem();
  public ClusterInterceptorListFluent.ItemsNested<A> editLastItem();
  public ClusterInterceptorListFluent.ItemsNested<A> editMatchingItem(Predicate<ClusterInterceptorBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ClusterInterceptorFluent<ClusterInterceptorListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> tekton-model-triggers-v1alpha1-6.7.1-sources.jar: io/fabric8/tekton/triggers/v1alpha1/ClusterInterceptorListFluent.java <==
package io.fabric8.tekton.triggers.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface ClusterInterceptorListFluent<A extends ClusterInterceptorListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,ClusterInterceptor item);
  public A setToItems(int index,ClusterInterceptor item);
  public A addToItems(io.fabric8.tekton.triggers.v1alpha1.ClusterInterceptor... items);
  public A addAllToItems(Collection<ClusterInterceptor> items);
  public A removeFromItems(io.fabric8.tekton.triggers.v1alpha1.ClusterInterceptor... items);
  public A removeAllFromItems(Collection<ClusterInterceptor> items);
  public A removeMatchingFromItems(Predicate<ClusterInterceptorBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ClusterInterceptor> getItems();
  public List<ClusterInterceptor> buildItems();
  public ClusterInterceptor buildItem(int index);
  public ClusterInterceptor buildFirstItem();
  public ClusterInterceptor buildLastItem();
  public ClusterInterceptor buildMatchingItem(Predicate<ClusterInterceptorBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ClusterInterceptorBuilder> predicate);
  public A withItems(List<ClusterInterceptor> items);
  public A withItems(io.fabric8.tekton.triggers.v1alpha1.ClusterInterceptor... items);
  public Boolean hasItems();
  public ClusterInterceptorListFluent.ItemsNested<A> addNewItem();
  public ClusterInterceptorListFluent.ItemsNested<A> addNewItemLike(ClusterInterceptor item);
  public ClusterInterceptorListFluent.ItemsNested<A> setNewItemLike(int index,ClusterInterceptor item);
  public ClusterInterceptorListFluent.ItemsNested<A> editItem(int index);
  public ClusterInterceptorListFluent.ItemsNested<A> editFirstItem();
  public ClusterInterceptorListFluent.ItemsNested<A> editLastItem();
  public ClusterInterceptorListFluent.ItemsNested<A> editMatchingItem(Predicate<ClusterInterceptorBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,ClusterInterceptorFluent<ClusterInterceptorListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
